@@ -38,7 +38,7 @@ static const char *gearman_worker_source_name(void *source) {
     return "Mod-Gearman Worker";
 }
 
-struct check_engine mod_gearman_check_engine = {
+static struct check_engine mod_gearman_check_engine = {
     "Mod-Gearman",
     gearman_worker_source_name,
     NULL
@@ -322,7 +322,7 @@ void *get_results( gearman_job_st *job, void *context, size_t *result_size, gear
             return NULL;
         }
 #endif
-        gm_log( GM_LOG_DEBUG, "service job completed: %s %s: %d\n", chk_result->host_name, chk_result->service_description, chk_result->return_code );
+        gm_log( GM_LOG_DEBUG, "service job completed: %s %s: exit %d, latency: %0.3f, exec_time: %0.3f\n", chk_result->host_name, chk_result->service_description, chk_result->return_code, chk_result->latency, exec_time );
     } else {
 #ifdef GM_DEBUG
         /* does this host exist */
@@ -342,7 +342,7 @@ void *get_results( gearman_job_st *job, void *context, size_t *result_size, gear
             }
         }
 #endif
-        gm_log( GM_LOG_DEBUG, "host job completed: %s: %d\n", chk_result->host_name, chk_result->return_code );
+        gm_log( GM_LOG_DEBUG, "host job completed: %s: exit %d, latency: %0.3f, exec_time: %0.3f\n", chk_result->host_name, chk_result->return_code, chk_result->latency, exec_time );
     }
 
     /* add result to result list */
